#ifndef NT2_INCLUDE_FUNCTIONS_MINNUM_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MINNUM_HPP_INCLUDED

#include <nt2/ieee/include/functions/minnum.hpp>

#endif
